@@ -38,6 +38,7 @@ typedef PangoEngineShapeClass ArabicEngineFcClass ;
 
 static PangoEngineScriptInfo arabic_scripts[] = {
   { PANGO_SCRIPT_ARABIC, "*" },
+  { PANGO_SCRIPT_NKO, "*" }
 };
 
 static PangoEngineInfo script_engines[] = {
@@ -104,20 +105,6 @@ arabic_engine_shape (PangoEngineShape *engine,
   if (!face)
     return;
 
-  desc.script = analysis->script;
-  desc.language = analysis->language;
-
-  desc.n_static_gsub_features = G_N_ELEMENTS (gsub_features);
-  desc.static_gsub_features = gsub_features;
-  desc.n_static_gpos_features = G_N_ELEMENTS (gpos_features);
-  desc.static_gpos_features = gpos_features;
-
-  /* TODO populate other_features from analysis->extra_attrs */
-  desc.n_other_features = 0;
-  desc.other_features = NULL;
-
-  ruleset = pango_ot_ruleset_get_for (pango_ot_info_get (face), &desc);
-
   buffer = pango_ot_buffer_new (fc_font);
   pango_ot_buffer_set_rtl (buffer, analysis->level % 2 != 0);
   pango_ot_buffer_set_zero_width_marks (buffer, TRUE);
@@ -173,6 +160,20 @@ arabic_engine_shape (PangoEngineShape *engine,
 
   g_free (properties);
 
+  desc.script = analysis->script;
+  desc.language = analysis->language;
+
+  desc.n_static_gsub_features = G_N_ELEMENTS (gsub_features);
+  desc.static_gsub_features = gsub_features;
+  desc.n_static_gpos_features = G_N_ELEMENTS (gpos_features);
+  desc.static_gpos_features = gpos_features;
+
+  /* TODO populate other_features from analysis->extra_attrs */
+  desc.n_other_features = 0;
+  desc.other_features = NULL;
+
+  ruleset = pango_ot_ruleset_get_for_description (pango_ot_info_get (face), &desc);
+
   pango_ot_ruleset_substitute (ruleset, buffer);
   pango_ot_ruleset_position (ruleset, buffer);
   pango_ot_buffer_output (buffer, glyphs);
