@@ -557,7 +557,6 @@ static const GMarkupParser pango_markup_parser = {
  * @accel_char: address of return location for accelerator char, or %NULL
  * @error: address of return location for errors, or %NULL
  *
- *
  * Parses marked-up text (see
  * <link linkend="PangoMarkupFormat">markup format</link>) to create
  * a plain-text string and an attribute list.
@@ -570,6 +569,9 @@ static const GMarkupParser pango_markup_parser = {
  * Two @accel_marker characters following each other produce a single
  * literal @accel_marker character.
  *
+ * If any error happens, none of the output arguments are touched except
+ * for @error.
+ *
  * Return value: %FALSE if @error is set, otherwise %TRUE
  **/
 gboolean
@@ -664,7 +666,7 @@ pango_parse_markup (const char                 *markup_text,
 	  PangoAttribute *attr = tmp_list->data;
 
 	  /* Innermost tags before outermost */
-	  pango_attr_list_change (md->attr_list, attr);
+	  pango_attr_list_insert (md->attr_list, attr);
 
 	  tmp_list = g_slist_next (tmp_list);
 	}
