@@ -38,7 +38,7 @@ pango_cairo_fc_font_map_set_resolution (PangoCairoFontMap *cfontmap,
 					double             dpi)
 {
   PangoCairoFcFontMap *cffontmap = (PangoCairoFcFontMap *) (cfontmap);
-  
+
   cffontmap->dpi = dpi;
 
   pango_fc_font_map_cache_clear ((PangoFcFontMap *) (cfontmap));
@@ -52,15 +52,10 @@ pango_cairo_fc_font_map_get_resolution_cairo (PangoCairoFontMap *cfontmap)
   return cffontmap->dpi;
 }
 
-static PangoRenderer *
-pango_cairo_fc_font_map_get_renderer (PangoCairoFontMap *cfontmap)
+static cairo_font_type_t
+pango_cairo_fc_font_map_get_font_type (PangoCairoFontMap *cfontmap)
 {
-  PangoCairoFcFontMap *cffontmap = (PangoCairoFcFontMap *) (cfontmap);
-  
-  if (!cffontmap->renderer)
-    cffontmap->renderer = g_object_new (PANGO_TYPE_CAIRO_RENDERER, NULL);
-
-  return cffontmap->renderer;
+  return CAIRO_FONT_TYPE_FT;
 }
 
 static void
@@ -68,7 +63,7 @@ cairo_font_map_iface_init (PangoCairoFontMapIface *iface)
 {
   iface->set_resolution = pango_cairo_fc_font_map_set_resolution;
   iface->get_resolution = pango_cairo_fc_font_map_get_resolution_cairo;
-  iface->get_renderer = pango_cairo_fc_font_map_get_renderer;
+  iface->get_font_type  = pango_cairo_fc_font_map_get_font_type;
 }
 
 G_DEFINE_TYPE_WITH_CODE (PangoCairoFcFontMap, pango_cairo_fc_font_map, PANGO_TYPE_FC_FONT_MAP,
@@ -78,7 +73,7 @@ static void
 pango_cairo_fc_font_map_finalize (GObject *object)
 {
   PangoCairoFcFontMap *cffontmap = (PangoCairoFcFontMap *) (object);
-  
+
   if (cffontmap->renderer)
     g_object_unref (cffontmap->renderer);
 
@@ -94,9 +89,10 @@ pango_cairo_fc_font_map_context_substitute (PangoFcFontMap *fcfontmap,
 {
   FcConfigSubstitute (NULL, pattern, FcMatchPattern);
 
-  cairo_ft_font_options_substitute (_pango_cairo_context_get_merged_font_options (context),
-				    pattern);
-  
+  if (context)
+    cairo_ft_font_options_substitute (_pango_cairo_context_get_merged_font_options (context),
+				      pattern);
+
   FcDefaultSubstitute (pattern);
 }
 
@@ -106,11 +102,11 @@ pango_cairo_fc_font_map_get_resolution_fc (PangoFcFontMap *fcfontmap,
 {
   PangoCairoFcFontMap *cffontmap = (PangoCairoFcFontMap *) (fcfontmap);
   double dpi;
-  
+
   if (context)
     {
       dpi = pango_cairo_context_get_resolution (context);
-      
+
       if (dpi <= 0)
 	dpi = cffontmap->dpi;
     }
@@ -156,7 +152,7 @@ pango_cairo_fc_font_map_context_key_equal (PangoFcFontMap *fcfontmap,
 {
   return cairo_font_options_equal (key_a, key_b);
 }
-  
+
 static PangoFcFont *
 pango_cairo_fc_font_map_create_font (PangoFcFontMap             *fcfontmap,
 				     PangoContext               *context,
@@ -174,16 +170,16 @@ pango_cairo_fc_font_map_class_init (PangoCairoFcFontMapClass *class)
   PangoFcFontMapClass *fcfontmap_class = PANGO_FC_FONT_MAP_CLASS (class);
 
   gobject_class->finalize  = pango_cairo_fc_font_map_finalize;
-  
+
   fcfontmap_class->context_substitute = pango_cairo_fc_font_map_context_substitute;
   fcfontmap_class->get_resolution = pango_cairo_fc_font_map_get_resolution_fc;
-  
+
   fcfontmap_class->context_key_get = pango_cairo_fc_font_map_context_key_get;
   fcfontmap_class->context_key_copy = pango_cairo_fc_font_map_context_key_copy;
   fcfontmap_class->context_key_free = pango_cairo_fc_font_map_context_key_free;
   fcfontmap_class->context_key_hash = pango_cairo_fc_font_map_context_key_hash;
   fcfontmap_class->context_key_equal = pango_cairo_fc_font_map_context_key_equal;
-  
+
   fcfontmap_class->create_font = pango_cairo_fc_font_map_create_font;
 }
 
